==> eslint-plugin-jsx-a11y-1.0.2.tgz: package/lib/rules/onclick-has-focus.js <==
/**
 * @fileoverview Enforce that elements with onClick handlers must be focusable.
 * @author Ethan Cohen
 */
'use strict';

var _isHiddenFromScreenReader = require('../util/isHiddenFromScreenReader');

var _isHiddenFromScreenReader2 = _interopRequireDefault(_isHiddenFromScreenReader);

var _isInteractiveElement = require('../util/isInteractiveElement');

var _isInteractiveElement2 = _interopRequireDefault(_isInteractiveElement);

var _getAttribute = require('../util/getAttribute');

var _getAttribute2 = _interopRequireDefault(_getAttribute);

var _getNodeType = require('../util/getNodeType');

var _getNodeType2 = _interopRequireDefault(_getNodeType);

var _getAttributeValue = require('../util/getAttributeValue');

var _getAttributeValue2 = _interopRequireDefault(_getAttributeValue);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var errorMessage = 'Elements with onClick handlers must be focusable. ' + 'Either set the tabIndex property (usually 0), or use an element type which ' + 'is inherently focusable such as `button`.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var attributes = node.attributes;

      if ((0, _getAttribute2.default)(attributes, 'onClick') === undefined) {
        return;
      }

      var type = (0, _getNodeType2.default)(node);

      if ((0, _isHiddenFromScreenReader2.default)(type, attributes)) {
        return;
      } else if ((0, _isInteractiveElement2.default)(type, attributes)) {
        return;
      } else if ((0, _getAttributeValue2.default)((0, _getAttribute2.default)(attributes, 'tabIndex'))) {
        return;
      }

      context.report({
        node: node,
        message: errorMessage
      });
    }
  };
};

module.exports.schema = [{ type: 'object' }];

==> eslint-plugin-jsx-a11y-1.3.0.tgz: package/lib/rules/onclick-has-focus.js <==
/**
 * @fileoverview Enforce that elements with onClick handlers must be focusable.
 * @author Ethan Cohen
 */
'use strict';

var _isHiddenFromScreenReader = require('../util/isHiddenFromScreenReader');

var _isHiddenFromScreenReader2 = _interopRequireDefault(_isHiddenFromScreenReader);

var _isInteractiveElement = require('../util/isInteractiveElement');

var _isInteractiveElement2 = _interopRequireDefault(_isInteractiveElement);

var _getAttribute = require('../util/getAttribute');

var _getAttribute2 = _interopRequireDefault(_getAttribute);

var _getNodeType = require('../util/getNodeType');

var _getNodeType2 = _interopRequireDefault(_getNodeType);

var _getTabIndex = require('../util/getTabIndex');

var _getTabIndex2 = _interopRequireDefault(_getTabIndex);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var errorMessage = 'Elements with onClick handlers must be focusable. ' + 'Either set the tabIndex property to a valid value (usually 0), or use ' + 'an element type which is inherently focusable such as `button`.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var attributes = node.attributes;

      if ((0, _getAttribute2.default)(attributes, 'onClick') === undefined) {
        return;
      }

      var type = (0, _getNodeType2.default)(node);

      if ((0, _isHiddenFromScreenReader2.default)(type, attributes)) {
        return;
      } else if ((0, _isInteractiveElement2.default)(type, attributes)) {
        return;
      } else if ((0, _getTabIndex2.default)((0, _getAttribute2.default)(attributes, 'tabIndex')) !== undefined) {
        return;
      }

      context.report({
        node: node,
        message: errorMessage
      });
    }
  };
};

module.exports.schema = [{ type: 'object' }];
